@@ -2,7 +2,7 @@ from __future__ import division, absolute_import, print_function
 import numpy as np
 
 
-def local_linear_1d(bw, xdata, ydata, points, output=None):
+def local_linear_1d(bw, xdata, ydata, points, out=None):
     points = np.atleast_1d(points).astype(xdata.dtype)
     x0 = points - xdata[:, np.newaxis]
     x02 = x0 * x0
@@ -13,4 +13,4 @@ def local_linear_1d(bw, xdata, ydata, points, output=None):
     Y = np.sum(wy, axis=0)
     Y2 = np.sum(wy * x0, axis=0)
     W = np.sum(wi, axis=0)
-    return None, np.divide(X2 * Y - Y2 * X, W * X2 - X * X, output)
+    return None, np.divide(X2 * Y - Y2 * X, W * X2 - X * X, out)
